@@ -6,8 +6,8 @@ import zlib as _zlib
 import numpy as np
 
 
-from numcodecs.abc import Codec
-from numcodecs.compat import buffer_copy
+from .abc import Codec
+from .compat import buffer_copy, handle_datetime
 
 
 class Zlib(Codec):
@@ -27,9 +27,18 @@ class Zlib(Codec):
 
     def encode(self, buf):
 
-        # if numpy array, can only handle C contiguous directly
-        if isinstance(buf, np.ndarray) and not buf.flags.c_contiguous:
-            buf = buf.tobytes(order='A')
+        # deal with lack of buffer support for datetime64 and timedelta64
+        buf = handle_datetime(buf)
+
+        if isinstance(buf, np.ndarray):
+
+            # cannot compress object array
+            if buf.dtype == object:
+                raise ValueError('cannot encode object array')
+
+            # if numpy array, can only handle C contiguous directly
+            if not buf.flags.c_contiguous:
+                buf = buf.tobytes(order='A')
 
         # do compression
         return _zlib.compress(buf, self.level)
